==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/ActioncardRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Actioncard;
import microsoft.dynamics.crm.entity.collection.request.ActioncarduserstateCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class ActioncardRequest extends EntityRequest<Actioncard> {

    public ActioncardRequest(ContextPath contextPath, Optional<Object> value) {
        super(Actioncard.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public LetterRequest regardingobjectid_letter_actioncard() {
        return new LetterRequest(contextPath.addSegment("regardingobjectid_letter_actioncard"), Optional.empty());
    }

    public PhonecallRequest regardingobjectid_phonecall_actioncard() {
        return new PhonecallRequest(contextPath.addSegment("regardingobjectid_phonecall_actioncard"), Optional.empty());
    }

    public FaxRequest regardingobjectid_fax_actioncard() {
        return new FaxRequest(contextPath.addSegment("regardingobjectid_fax_actioncard"), Optional.empty());
    }

    public BusinessunitRequest owningbusinessunit() {
        return new BusinessunitRequest(contextPath.addSegment("owningbusinessunit"), Optional.empty());
    }

    public TransactioncurrencyRequest transactioncurrencyid() {
        return new TransactioncurrencyRequest(contextPath.addSegment("transactioncurrencyid"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public PrincipalRequest ownerid() {
        return new PrincipalRequest(contextPath.addSegment("ownerid"), Optional.empty());
    }

    public ContactRequest regardingobjectid_contact_actioncard() {
        return new ContactRequest(contextPath.addSegment("regardingobjectid_contact_actioncard"), Optional.empty());
    }

    public ActioncarduserstateCollectionRequest actionCardUserState_ActionCard() {
        return new ActioncarduserstateCollectionRequest(
                        contextPath.addSegment("ActionCardUserState_ActionCard"), Optional.empty());
    }

    public ActioncarduserstateRequest actionCardUserState_ActionCard(String actioncarduserstateid) {
        return new ActioncarduserstateRequest(contextPath.addSegment("ActionCardUserState_ActionCard").addKeys(new NameValue(actioncarduserstateid.toString())), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public EmailRequest regardingobjectid_email_actioncard() {
        return new EmailRequest(contextPath.addSegment("regardingobjectid_email_actioncard"), Optional.empty());
    }

    public AppointmentRequest regardingobjectid_appointment_actioncard() {
        return new AppointmentRequest(contextPath.addSegment("regardingobjectid_appointment_actioncard"), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public RecurringappointmentmasterRequest regardingobjectid_recurringappointmentmaster_actioncard() {
        return new RecurringappointmentmasterRequest(contextPath.addSegment("regardingobjectid_recurringappointmentmaster_actioncard"), Optional.empty());
    }

    public AccountRequest regardingobjectid_account_actioncard() {
        return new AccountRequest(contextPath.addSegment("regardingobjectid_account_actioncard"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public TaskRequest regardingobjectid_task_actioncard() {
        return new TaskRequest(contextPath.addSegment("regardingobjectid_task_actioncard"), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.53-sources.jar: microsoft/dynamics/crm/entity/request/ActioncardRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Actioncard;
import microsoft.dynamics.crm.entity.collection.request.ActioncarduserstateCollectionRequest;

@JsonIgnoreType
public class ActioncardRequest extends EntityRequest<Actioncard> {

    public ActioncardRequest(ContextPath contextPath, Optional<Object> value) {
        super(Actioncard.class, contextPath, value);
    }

    public LetterRequest regardingobjectid_letter_actioncard() {
        return new LetterRequest(contextPath.addSegment("regardingobjectid_letter_actioncard"), Optional.empty());
    }

    public PhonecallRequest regardingobjectid_phonecall_actioncard() {
        return new PhonecallRequest(contextPath.addSegment("regardingobjectid_phonecall_actioncard"), Optional.empty());
    }

    public FaxRequest regardingobjectid_fax_actioncard() {
        return new FaxRequest(contextPath.addSegment("regardingobjectid_fax_actioncard"), Optional.empty());
    }

    public BusinessunitRequest owningbusinessunit() {
        return new BusinessunitRequest(contextPath.addSegment("owningbusinessunit"), Optional.empty());
    }

    public TransactioncurrencyRequest transactioncurrencyid() {
        return new TransactioncurrencyRequest(contextPath.addSegment("transactioncurrencyid"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public PrincipalRequest ownerid() {
        return new PrincipalRequest(contextPath.addSegment("ownerid"), Optional.empty());
    }

    public ContactRequest regardingobjectid_contact_actioncard() {
        return new ContactRequest(contextPath.addSegment("regardingobjectid_contact_actioncard"), Optional.empty());
    }

    public ActioncarduserstateCollectionRequest actionCardUserState_ActionCard() {
        return new ActioncarduserstateCollectionRequest(
                        contextPath.addSegment("ActionCardUserState_ActionCard"), Optional.empty());
    }

    public ActioncarduserstateRequest actionCardUserState_ActionCard(String actioncarduserstateid) {
        return new ActioncarduserstateRequest(contextPath.addSegment("ActionCardUserState_ActionCard").addKeys(new NameValue(actioncarduserstateid.toString())), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public EmailRequest regardingobjectid_email_actioncard() {
        return new EmailRequest(contextPath.addSegment("regardingobjectid_email_actioncard"), Optional.empty());
    }

    public AppointmentRequest regardingobjectid_appointment_actioncard() {
        return new AppointmentRequest(contextPath.addSegment("regardingobjectid_appointment_actioncard"), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public RecurringappointmentmasterRequest regardingobjectid_recurringappointmentmaster_actioncard() {
        return new RecurringappointmentmasterRequest(contextPath.addSegment("regardingobjectid_recurringappointmentmaster_actioncard"), Optional.empty());
    }

    public AccountRequest regardingobjectid_account_actioncard() {
        return new AccountRequest(contextPath.addSegment("regardingobjectid_account_actioncard"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public TaskRequest regardingobjectid_task_actioncard() {
        return new TaskRequest(contextPath.addSegment("regardingobjectid_task_actioncard"), Optional.empty());
    }

}
